PointerDerefMut

Trait PointerDerefMut 

pub unsafe trait PointerDerefMut: PointerDeref + DerefMut { }
Trait that allows to create a mutable reference to the pointed-at object.

Safety

Implementer must guarantee safety of creating, using and keeping of mutable reference from the raw pointer returned by PointerLike::into_ptr. It must also be allowed to operate on this raw pointer in the manner of a mutable reference.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Ptr: PointerDerefMut> PointerDerefMut for Pin<Ptr>
where Ptr::Pointee: Unpin,

Source

impl<T> PointerDerefMut for &mut T

Source

impl<T> PointerDerefMut for Box<T>

Implementors

Source

impl<T> PointerDerefMut for RefOnce<'_, T>