pub const unsafe fn fn_drop<P: PointerLike>() -> impl Fn(*mut ()) + Copy + Send + Sync + UnwindSafe + RefUnwindSafe + Unpin + 'staticExpand description
Get 'static function of drop on a P pointer type.
Safety
Only valid pointers of the same original smart-pointer type P must be passed to the returned
closure otherwise causing undefined behaviour.